@@ -3,7 +3,7 @@ source(file.path(R.home("share"), "R", "examples-header.R"))
 options(warn = 1)
 library('rasterVis')
 
-assign(".oldSearch", search(), pos = 'CheckExEnv')
+base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
 cleanEx()
 nameEx("bwplot-methods")
 ### * bwplot-methods
@@ -477,6 +477,34 @@ f <- system.file("external/test.grd", package="raster")
 r <- raster(f)
 levelplot(r)
 
+## Change the color theme
+levelplot(r, par.settings=GrTheme())
+levelplot(r, par.settings=PuOrTheme())
+
+myTheme=rasterTheme(region=brewer.pal('Blues', n=9))
+levelplot(r, par.settings=myTheme)
+
+## Define the legend breaks
+my.at <- seq(100, 1850, 500)
+levelplot(r, at=my.at)
+
+myColorkey <- list(at=my.at, ## where the colors change
+                   labels=list(
+                     at=my.at ## where to print labels
+                     ))
+levelplot(r, at=my.at, colorkey=myColorkey)
+
+myColorkey <- list(at=my.at, ## where the colors change
+                   labels=list(
+                     labels=letters[seq_along(my.at)], ## labels
+                     at=my.at ## where to print labels
+                     ))
+levelplot(r, at=my.at, colorkey=myColorkey)
+
+## shrink and border color
+rCenter <- (maxValue(r) + minValue(r)) / 2
+levelplot(r - rCenter, par.settings=RdBuTheme(), shrink=c(.8, 15), border='black')
+
 ## With subticks
 levelplot(r, xscale.components=xscale.raster.subticks,
              yscale.components=yscale.raster.subticks)
@@ -485,20 +513,36 @@ levelplot(r, xscale.components=xscale.raster.subticks,
              yscale.components=yscale.raster.subticks,
              scales=list(x=list(rot=30, cex=0.8)))
 
-## defining the scales for the marginal plot
-levelplot(r, scales.margin=list(x=c(100, 600), y=c(100, 1000)))
-## if a component of the list is null, it is internally calculated
-levelplot(r, scales.margin=list(x=c(100, 1000)))
-
 ## log-scale
 levelplot(r^2, zscaleLog=TRUE, contour=TRUE)
 
+## Customizing axis and title labels
+levelplot(r, margin=FALSE,
+          main=list('My plot', col='red'),
+          xlab=c('This is the', 'X-Axis'),
+          ylab=list('Y-Axis', rot=30, fontface='bold')
+          )
+
+## xlim and ylim to display a smaller region
+levelplot(r, xlim=c(179000, 181000), ylim=c(329500, 334000))
+
+## RasterStacks
 s <- stack(r, r+500, r-500)
 levelplot(s, contour=TRUE)
 contourplot(s, labels=list(cex=0.4), cuts=12)
 
+## Use of layout
+levelplot(s, layout=c(1, 3))
+levelplot(s, layout=c(1, 1))
+
+## names.attr to change the labels of each panel
 levelplot(s, names.attr=c('R', 'R + 500', 'R - 500'))
 
+## defining the scales for the marginal plot
+levelplot(r, scales.margin=list(x=c(100, 600), y=c(100, 1000)))
+## if a component of the list is null, it is internally calculated
+levelplot(r, scales.margin=list(x=c(100, 1000)))
+
 ## Add a layer of sampling points
 ## and change the theme
 pts <- sampleRandom(r, size=20, sp=TRUE)
@@ -524,11 +568,16 @@ r <- ratify(r)
      
 rat <- levels(r)[[1]]
 rat$landcover <- c('Pine', 'Oak', 'Meadow')
+rat$class <- c('A1', 'B2', 'C3')
 levels(r) <- rat
 r
 
 levelplot(r, col.regions=c('palegreen', 'midnightblue', 'indianred1'))
 
+## with 'att' you can choose another variable from the RAT
+levelplot(r, att=2, col.regions=c('palegreen', 'midnightblue', 'indianred1'))
+levelplot(r, att='class', col.regions=c('palegreen', 'midnightblue', 'indianred1'))
+
 r2 <- raster(r)
 r2[] = 3
 r2[51:100] = 1
@@ -543,7 +592,7 @@ s <- stack(r, r2, r3)
 names(s) <- c('A', 'B', 'C')
 
 levelplot(s)
-
+levelplot(s, att=2)
 
 ## Not run: 
 ##D ##Solar irradiation data from CMSAF
@@ -741,7 +790,7 @@ flush(stderr()); flush(stdout())
 
 ### * <FOOTER>
 ###
-cat("Time elapsed: ", proc.time() - get("ptime", pos = 'CheckExEnv'),"\n")
+base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
 grDevices::dev.off()
 ###
 ### Local variables: ***
